/*
 * SimPowReg.c
 *
 * Created: 30.01.2018 09:11:17
 *  Author: dsosnowski
 */ 

//---------------------------------------------------
#define F_CPU					8000000
#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include "wdog.h"
#include "display.h"
#include "buttons.h"
#include "phase.h"
#include "ee_mem.h"

#define MAIN_DELAY				10

#define VOLUME_MAX				100
#define VOLUME_MIN				0

#define SAVE_DELAY				255
#define SAVE_MEM_ADR			4
	

//---------------------------------------------------
int main(void)
{
	uint8_t action = 0;
	uint8_t reg = 0;
	uint8_t refresh = 0;
	uint8_t needSave = 0;
	
	WdtSet(7);
	ButtonInit();
	DispInit();                   
	DispMsg("HELLO", 0, 0);
	
	reg = EEread(SAVE_MEM_ADR);
	if (reg > VOLUME_MAX) reg = VOLUME_MIN;
	
	_delay_ms(800);
	refresh = 1;
	
	PhaseInit();
	sei();
	
	//---------------------------------------------------
    while(1)
    {
	    //---------------------------------------------------
        action = ButtonProc();
		if (action > 0) {							
			if (action == BUTTON1_CLICK){
				if (reg < VOLUME_MAX) reg++;
				refresh = 1;
				needSave = SAVE_DELAY;
			}
			if (action == BUTTON2_CLICK){
				if (reg > VOLUME_MIN) reg--;
				refresh = 1;
				needSave = SAVE_DELAY;
			}			
		}
							
		if (refresh > 0){
			PhasePowerSet(reg);
			DispMsg(" ", 0, 0);
			DispSimpleValue((uint16_t)reg);
			DispText("% ");
			refresh = 0;
		}
		
		if (needSave > 0){
			needSave--;
			if (needSave == 0){
				EEwrite(SAVE_MEM_ADR, reg);
			}
		}
		
		//---------------------------------------------------
		_delay_ms(MAIN_DELAY);
		WdtReset();
    }
}


